
This package prices options by the binomial tree method. Currently, european and american options can be priced.
Plan to add support for custom payoff functions, probabilties at each node and volatility estimation. 


Provides the output graph along with information for the replicating portfolio and derivative price at each node.

